@@ -18,12 +18,15 @@ TypingSet = "Set"
 TypingDict = "Dict"
 TypingType = "Type"
 TypingUnion = "Union"
+TypingForwardRef = "ForwardRef"
 
 EXPackField = "__ex_pack_field__"
 DataClassFields = '__dataclass_fields__'
 AsdictFuncPrefix = "asdict"
 LoadsFuncPrefix = "loads"
 
+E_CLASS_CACHE = dict()
+
 
 # transfer function type
 def asdict_xxxFieldName(value: typing.Any) -> F_VALUE:
